==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="az" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Doğrulama vaxtı bitdi</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk məşğuldur, indi ayrıla bilməz</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk məşğuldur, indi çıxarıla bilməz</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Cihaz məşğuldur, indi çıxarıla bilməz</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Cihaz məşğuldur, indi ayrıla bilməz</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 disk tutumu</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Naməlum</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Cihaz təhlükəsiz şəkildə çıxarılmadı</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Növbəti dəfə &quot;Təhlükəsiz Çıxartmaq&quot; vurun və sonra çıxardın</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Cihaz məşğuldur, indi çıxarıla bilməz</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Cihaz məşğuldur, indi ayrıla bilməz</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Cihazı ayırmaq mümkün deyil</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk &quot;%1&quot; istifadəçisi tərəfindən qoşulub, siz onu ayıra bilməzsiniz.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Qoşulmuş cihazı tapmaq olmur</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disklər</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Hamısını çıxartmaq</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Bu cihaz təhlükəsiz çıxarıldı</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>İcazə verilmədi</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Bu qovluğa girməniz üçün icazəniz yoxdur</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Tədiqləmək</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Cihazlar aşkarlanır, dayandırılsın?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Dayandırmaq</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.1.orig.tar.xz: dde-file-manager-5.8.1/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Doğrulama vaxtı bitdi</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disk məşğuldur, indi ayrıla bilməz</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disk məşğuldur, indi çıxarıla bilməz</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Cihaz məşğuldur, indi çıxarıla bilməz</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Cihaz məşğuldur, indi ayrıla bilməz</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 disk tutumu</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Naməlum</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Cihaz təhlükəsiz şəkildə çıxarılmadı</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Növbəti dəfə &quot;Təhlükəsiz Çıxartmaq&quot; vurun və sonra çıxardın</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Cihazı ayırmaq mümkün deyil</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disk &quot;%1&quot; istifadəçisi tərəfindən qoşulub, siz onu ayıra bilməzsiniz.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Qoşulmuş cihazı tapmaq olmur</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disklər</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Hamısını çıxartmaq</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Bu cihaz təhlükəsiz çıxarıldı</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>İcazə verilmədi</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Bu qovluğa girməniz üçün icazəniz yoxdur</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Cihazlar aşkarlanır, dayandırılsın?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Tədiqləmək</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Dayandırmaq</translation>
    </message>
</context>
</TS>
